#
# spec file for package scanmem
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           scanmem
Version:        0.17
Release:        bp156.4.6
Summary:        Interactive debugging utility
License:        GPL-3.0-only
URL:            https://github.com/scanmem/scanmem
Source0:        https://github.com/scanmem/scanmem/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch1:         fix-build-with-older-autotools.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  readline-devel

%description
scanmem is a debugging utility designed to isolate the address of an
arbitrary variable in an executing process. scanmem simply needs to be told
the PID of the process, and the value of the variable at several different
times. After several scans of the process, scanmem isolates the position of
the variable and allows you to modify its value.

%prep
%setup -q
%patch1 -p1

%build
autoreconf -fiv
intltoolize
%configure --libdir=%{_libdir}/scanmem
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f \( -name '*.a' -o -name '*.la' \) -delete -print
find %{buildroot} -type l \( -name '*.so' \) -delete -print
rm -rf %{buildroot}%{_includedir}/scanmem

%files
%defattr(-,root,root)
%{_bindir}/scanmem
%dir %{_libdir}/scanmem
%{_libdir}/scanmem/libscanmem.so.*
%{_datadir}/doc/scanmem
%{_mandir}/man1/scanmem.1%{?ext_man}

%changelog
* Mon Oct 21 2019 Sebastian Parschauer <s.parschauer@gmx.de> - 0.17-1
- Update the spec file by running spec-cleaner
- Update patches to final upstream description
  * update: fix-build-with-older-autotools.patch
* Tue Jan  9 2018 sparschauer@suse.de
- Update to version 0.17:
  * major performance improvement by inlining, new algorithms, and
    data as well as code optimization
  * complete string and bytearray search rework
  * fixed unaligned pointer access during string search
  * added "-c/--command" option for commands to be run first
  * added "-e/--errexit" option to exit on initial command errors
  * added "!" alias for "shell" command
  * added "max_to_print" parameter to "list" command (default: 10k)
  * full support for sets of values for "delete", "dregion", and "set"
  * custom pager support (env $PAGER)
  * fixed listing floats with >100 digits
  * parse negative numbers as int64 instead of uint64
  * better checks if input is valid
  * autotools: don't make po/ files without GUI
  * added a testing framework
  * documentation fixes
- Fix the build with older autotools
  * add: fix-build-with-older-autotools.patch
* Sat Mar 11 2017 jengelh@inai.de
- Improve orthography and ensure neutrality of descriptions.
* Thu Feb 23 2017 sparschauer@suse.de
- Update to version 0.16:
  * add ranges support ("n..m" command)
  * use exact float matching (depends on ranges)
  * add Android support
  * change license to LGPL-3 for libscanmem
  * fix the watch handler to respect match flags
  * rework man pages
  * rework scanmem version printing and root warning
- Remove the hicolor-icon-theme build requirement as GameConqueror
  is not provided
- Don't provide libscanmem.so from the scanmem package
- Install libscanmem to /usr/lib(64)/scanmem to avoid that it is
  located in a library search path
* Tue May 31 2016 mpluskal@suse.com
- Update to version 0.15.8:
  * fixed project links
  * removed superfluous/auto-generated files
  * updated NEWS, ChangeLog, gameconqueror.1, scanmem.1
  * gui: Hide the AddCheatDialog if trying to delete it (#160)
  * menu: Fix the prototype of printversion()
  * gui: Set Gtk 3.0 requirement to avoid a warning
  * autogen: Run autoheader to generate config.h.in
  * gameconqueror.in: Get the pkexec path from shell
  * gameconqueror.in: Directly execute GameConqueror.py
  * scanmem: Initialize the reverse_endianness option
  * replaced deprecated GtkButton:use-stock and GtkImage:stock
* Tue May 31 2016 mpluskal@suse.com
- Initial package for version 0.15.7 (based on package from
  home:javilete)
